# FundingContributorV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**contributor_orcid** | [**ContributorOrcidV30Rc2**](ContributorOrcidV30Rc2.md) |  | [optional] 
**credit_name** | [**CreditNameV30Rc2**](CreditNameV30Rc2.md) |  | [optional] 
**contributor_email** | [**ContributorEmailV30Rc2**](ContributorEmailV30Rc2.md) |  | [optional] 
**contributor_attributes** | [**FundingContributorAttributesV30Rc2**](FundingContributorAttributesV30Rc2.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

